@@ -16,9 +16,9 @@
 
 static void
 _glibtop_missing_feature (glibtop *server, const char *feature,
-			  const u_int64_t present, u_int64_t *required)
+			  const guint64 present, guint64 *required)
 {
-	u_int64_t old_required = *required;
+	guint64 old_required = *required;
 
 	/* Return if we have all required fields. */
 	if ((~present & old_required) == 0)
