@@ -1,4 +1,4 @@
-/* $Id: read_data.c,v 1.14 2003/10/20 15:19:41 hadess Exp $ */
+/* $Id: read_data.c,v 1.15 2003/10/20 21:33:01 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -65,7 +65,7 @@ glibtop_read_data_l (glibtop *server)
 	}
 
 	if (ret < 0)
-		glibtop_error_io_r (server, _("read data %d bytes"));
+		glibtop_error_io_r (server, ngettext ("read data %d byte", "read data %d bytes", size));
 
 	return ptr;
 }
