@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.1.2.1 2002/12/30 16:15:12 hadess Exp $ */
+/* $Id: glibtop_machine.h,v 1.3 2003/10/20 15:19:46 hadess Exp $ */
 
 /* 
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 
 #include <procinfo.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef struct _glibtop_machine glibtop_machine;
 
@@ -48,6 +48,6 @@ struct _glibtop_machine
 	struct procsinfo last_pinfo;
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif /* __GLIBTOP_MACHINE_H__ */
