@@ -1,4 +1,4 @@
-/* $Id: prockernel.c,v 1.29 2003/10/19 16:55:32 carlos Exp $ */
+/* $Id: prockernel.c,v 1.30 2003/10/20 20:12:23 hadess Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -141,10 +141,10 @@ glibtop_get_proc_kernel_p (glibtop *server,
 			 * leave them 0.
 			 */
 
-			buf->min_flt = (u_int64_t) pstats.p_ru.ru_minflt;
-			buf->maj_flt = (u_int64_t) pstats.p_ru.ru_majflt;
-			buf->cmin_flt = (u_int64_t) pstats.p_cru.ru_minflt;
-			buf->cmaj_flt = (u_int64_t) pstats.p_cru.ru_majflt;
+			buf->min_flt = (guint64) pstats.p_ru.ru_minflt;
+			buf->maj_flt = (guint64) pstats.p_ru.ru_majflt;
+			buf->cmin_flt = (guint64) pstats.p_cru.ru_minflt;
+			buf->cmaj_flt = (guint64) pstats.p_cru.ru_majflt;
 			
 			buf->flags |= _glibtop_sysdeps_proc_kernel_pstats;
 		}
@@ -157,21 +157,21 @@ glibtop_get_proc_kernel_p (glibtop *server,
 #ifdef __FreeBSD__
 #ifndef __alpha__
 #if (__FreeBSD_version >= 300003)
-			buf->kstk_esp = (u_int64_t) pcb.pcb_esp;
-			buf->kstk_eip = (u_int64_t) pcb.pcb_eip;
+			buf->kstk_esp = (guint64) pcb.pcb_esp;
+			buf->kstk_eip = (guint64) pcb.pcb_eip;
 #else
-			buf->kstk_esp = (u_int64_t) pcb.pcb_ksp;
-			buf->kstk_eip = (u_int64_t) pcb.pcb_pc;
+			buf->kstk_esp = (guint64) pcb.pcb_ksp;
+			buf->kstk_eip = (guint64) pcb.pcb_pc;
 #endif
 #else
 			/*xxx FreeBSD/Alpha? */
 #endif
 #else
-			buf->kstk_esp = (u_int64_t) pcb.pcb_tss.tss_esp0;
+			buf->kstk_esp = (guint64) pcb.pcb_tss.tss_esp0;
 #ifdef __bsdi__
-			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.tss_eip;
+			buf->kstk_eip = (guint64) pcb.pcb_tss.tss_eip;
 #else
-			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.__tss_eip;
+			buf->kstk_eip = (guint64) pcb.pcb_tss.__tss_eip;
 #endif
 
 			buf->flags |= _glibtop_sysdeps_proc_kernel_pcb;
