@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.9 2003/10/20 15:19:59 hadess Exp $ */
+/* $Id: uptime.c,v 1.10 2003/10/20 21:27:27 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,22 +26,24 @@
 
 const char *glibtop_names_uptime [GLIBTOP_MAX_UPTIME] =
 {
-	"uptime", "idletime"
+	"uptime", "idletime", "boot_time"
 };
 
 const unsigned glibtop_types_uptime [GLIBTOP_MAX_UPTIME] =
 {
-	GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_DOUBLE
+	GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_DOUBLE, GLIBTOP_TYPE_ULONG
 };
 
 const char *glibtop_labels_uptime [GLIBTOP_MAX_UPTIME] =
 {
 	N_("Uptime"),
-	N_("Idletime")
+	N_("Idletime"),
+	N_("BootTime")
 };
 
 const char *glibtop_descriptions_uptime [GLIBTOP_MAX_UPTIME] =
 {
 	N_("Time in seconds since system boot"),
-	N_("Time in seconds the system spent in the idle task since system boot")
+	N_("Time in seconds the system spent in the idle task since system boot"),
+	N_("Time of last system boot in seconds since the epoch"),
 };
